@@ -33,9 +33,10 @@
 #  define KCOREADDONS_DEPRECATED_NO_EXPORT KCOREADDONS_NO_EXPORT KCOREADDONS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCOREADDONS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCOREADDONS_NO_DEPRECATED
+#    define KCOREADDONS_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* KCOREADDONS_EXPORT_H */
